# Use framebuffer by default if no XF86Config is found:
if [ ! -r etc/X11/XF86Config ]; then
  cp -a etc/X11/XF86Config-vesa etc/X11/XF86Config
fi
( cd usr/lib ; rm -rf terminfo )
( cd usr/lib ; ln -sf /usr/share/terminfo terminfo )
# Links for the terminfo subset:
( cd usr/share/terminfo/l ; rm -rf la120 )
( cd usr/share/terminfo/l ; ln -sf ../d/dw3 la120 )
( cd usr/share/terminfo/l ; rm -rf layer )
( cd usr/share/terminfo/l ; ln -sf ../a/att5620-s layer )
( cd usr/share/terminfo/l ; rm -rf lft-pc850 )
( cd usr/share/terminfo/l ; ln -sf ../l/lft lft-pc850 )
( cd usr/share/terminfo/l ; rm -rf luna68k )
( cd usr/share/terminfo/l ; ln -sf ../l/luna luna68k )
( cd usr/share/terminfo/n ; rm -rf nansisys )
( cd usr/share/terminfo/n ; ln -sf ../n/nansi.sys nansisys )
( cd usr/share/terminfo/n ; rm -rf nansisysk )
( cd usr/share/terminfo/n ; ln -sf ../n/nansi.sysk nansisysk )
( cd usr/share/terminfo/n ; rm -rf ncr260vt300wpp )
( cd usr/share/terminfo/n ; ln -sf ../N/NCR260VT300WPP ncr260vt300wpp )
( cd usr/share/terminfo/n ; rm -rf ncr7900 )
( cd usr/share/terminfo/n ; ln -sf ../n/ncr7900i ncr7900 )
( cd usr/share/terminfo/n ; rm -rf ncrvt100pp )
( cd usr/share/terminfo/n ; ln -sf ../n/ncrvt100an ncrvt100pp )
( cd usr/share/terminfo/n ; rm -rf ncrvt100wpp )
( cd usr/share/terminfo/n ; ln -sf ../n/ncrvt100wan ncrvt100wpp )
( cd usr/share/terminfo/n ; rm -rf ncsa-vt220-8 )
( cd usr/share/terminfo/n ; ln -sf ../n/ncsa-m ncsa-vt220-8 )
( cd usr/share/terminfo/n ; rm -rf nec )
( cd usr/share/terminfo/n ; ln -sf ../n/nec5520 nec )
( cd usr/share/terminfo/n ; rm -rf news )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512 news )
( cd usr/share/terminfo/n ; rm -rf news-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-a news-a )
( cd usr/share/terminfo/n ; rm -rf news-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-o news-o )
( cd usr/share/terminfo/n ; rm -rf news28-a )
( cd usr/share/terminfo/n ; ln -sf ../n/news29 news28-a )
( cd usr/share/terminfo/n ; rm -rf news31 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513 news31 )
( cd usr/share/terminfo/n ; rm -rf news31-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a news31-a )
( cd usr/share/terminfo/n ; rm -rf news31-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o news31-o )
( cd usr/share/terminfo/n ; rm -rf news33 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a news33 )
( cd usr/share/terminfo/n ; rm -rf news40 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512 news40 )
( cd usr/share/terminfo/n ; rm -rf news40-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-a news40-a )
( cd usr/share/terminfo/n ; rm -rf news40-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-o news40-o )
( cd usr/share/terminfo/n ; rm -rf news42 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-a news42 )
( cd usr/share/terminfo/n ; rm -rf newscbm )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513 newscbm )
( cd usr/share/terminfo/n ; rm -rf newscbm-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a newscbm-a )
( cd usr/share/terminfo/n ; rm -rf newscbm-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o newscbm-o )
( cd usr/share/terminfo/n ; rm -rf newscbm33 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a newscbm33 )
( cd usr/share/terminfo/n ; rm -rf nwe501 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513 nwe501 )
( cd usr/share/terminfo/n ; rm -rf nwe501-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a nwe501-a )
( cd usr/share/terminfo/n ; rm -rf nwe501-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o nwe501-o )
( cd usr/share/terminfo/n ; rm -rf nwp-511 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp511 nwp-511 )
( cd usr/share/terminfo/n ; rm -rf nwp-517 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp517 nwp-517 )
( cd usr/share/terminfo/n ; rm -rf nwp-517-w )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp517-w nwp-517-w )
( cd usr/share/terminfo/n ; rm -rf nwp251-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a nwp251-a )
( cd usr/share/terminfo/n ; rm -rf nwp251-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o nwp251-o )
( cd usr/share/terminfo/n ; rm -rf nwp514 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512 nwp514 )
( cd usr/share/terminfo/n ; rm -rf nwp514-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-a nwp514-a )
( cd usr/share/terminfo/n ; rm -rf nwp514-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-o nwp514-o )
( cd usr/share/terminfo/n ; rm -rf nwp518 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513 nwp518 )
( cd usr/share/terminfo/n ; rm -rf nwp518-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a nwp518-a )
( cd usr/share/terminfo/n ; rm -rf nwp518-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o nwp518-o )
( cd usr/share/terminfo/u ; rm -rf ultima2 )
( cd usr/share/terminfo/u ; ln -sf ../i/ims-ansi ultima2 )
( cd usr/share/terminfo/u ; rm -rf ultimaII )
( cd usr/share/terminfo/u ; ln -sf ../i/ims-ansi ultimaII )
( cd usr/share/terminfo/u ; rm -rf uniterm49 )
( cd usr/share/terminfo/u ; ln -sf ../u/uniterm uniterm49 )
( cd usr/share/terminfo/u ; rm -rf unixpc )
( cd usr/share/terminfo/u ; ln -sf ../a/att7300 unixpc )
( cd usr/share/terminfo/v ; rm -rf v200-nam )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-nam v200-nam )
( cd usr/share/terminfo/v ; rm -rf v320n )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320nam v320n )
( cd usr/share/terminfo/v ; rm -rf vapple )
( cd usr/share/terminfo/v ; ln -sf ../a/apple-videx3 vapple )
( cd usr/share/terminfo/v ; rm -rf vc103 )
( cd usr/share/terminfo/v ; ln -sf ../v/vc303 vc103 )
( cd usr/share/terminfo/v ; rm -rf vc203 )
( cd usr/share/terminfo/v ; ln -sf ../v/vc303 vc203 )
( cd usr/share/terminfo/v ; rm -rf vc403a )
( cd usr/share/terminfo/v ; ln -sf ../v/vc303a vc403a )
( cd usr/share/terminfo/v ; rm -rf vc414h )
( cd usr/share/terminfo/v ; ln -sf ../v/vc414 vc414h )
( cd usr/share/terminfo/v ; rm -rf venix )
( cd usr/share/terminfo/v ; ln -sf ../p/pc-venix venix )
( cd usr/share/terminfo/v ; rm -rf viewpoint3a+ )
( cd usr/share/terminfo/v ; ln -sf ../v/vp3a+ viewpoint3a+ )
( cd usr/share/terminfo/v ; rm -rf viewpoint60 )
( cd usr/share/terminfo/v ; ln -sf ../v/vp60 viewpoint60 )
( cd usr/share/terminfo/v ; rm -rf viewpoint90 )
( cd usr/share/terminfo/v ; ln -sf ../v/vp90 viewpoint90 )
( cd usr/share/terminfo/v ; rm -rf vip7800-H )
( cd usr/share/terminfo/v ; ln -sf ../v/vip-H vip7800-H )
( cd usr/share/terminfo/v ; rm -rf vip7800-Hw )
( cd usr/share/terminfo/v ; ln -sf ../v/vip-Hw vip7800-Hw )
( cd usr/share/terminfo/v ; rm -rf vip7800-w )
( cd usr/share/terminfo/v ; ln -sf ../v/vip-w vip7800-w )
( cd usr/share/terminfo/v ; rm -rf visual603 )
( cd usr/share/terminfo/v ; ln -sf ../v/vi603 visual603 )
( cd usr/share/terminfo/v ; rm -rf vitty )
( cd usr/share/terminfo/v ; ln -sf ../a/att5620-s vitty )
( cd usr/share/terminfo/v ; rm -rf vk100 )
( cd usr/share/terminfo/v ; ln -sf ../g/gigi vk100 )
( cd usr/share/terminfo/v ; rm -rf vs100 )
( cd usr/share/terminfo/v ; ln -sf ../x/xterm-24 vs100 )
( cd usr/share/terminfo/v ; rm -rf vs100-x10 )
( cd usr/share/terminfo/v ; ln -sf ../x/x10term vs100-x10 )
( cd usr/share/terminfo/v ; rm -rf vt-61 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt61 vt-61 )
( cd usr/share/terminfo/v ; rm -rf vt100-am )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100 vt100-am )
( cd usr/share/terminfo/v ; rm -rf vt100-bm )
( cd usr/share/terminfo/v ; ln -sf ../n/nwp512 vt100-bm )
( cd usr/share/terminfo/v ; rm -rf vt100-bm-o )
( cd usr/share/terminfo/v ; ln -sf ../n/nwp512-o vt100-bm-o )
( cd usr/share/terminfo/v ; rm -rf vt100-bot-s )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-s-bot vt100-bot-s )
( cd usr/share/terminfo/v ; rm -rf vt100-nam )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100nam vt100-nam )
( cd usr/share/terminfo/v ; rm -rf vt100-nam-w )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-w-nam vt100-nam-w )
( cd usr/share/terminfo/v ; rm -rf vt100-s-top )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-s vt100-s-top )
( cd usr/share/terminfo/v ; rm -rf vt100-top-s )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-s vt100-top-s )
( cd usr/share/terminfo/v ; rm -rf vt100-w-am )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-w vt100-w-am )
( cd usr/share/terminfo/v ; rm -rf vt100-w-nav )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-nav-w vt100-w-nav )
( cd usr/share/terminfo/v ; rm -rf vt200 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220 vt200 )
( cd usr/share/terminfo/v ; rm -rf vt200-8 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-8bit vt200-8 )
( cd usr/share/terminfo/v ; rm -rf vt200-8bit )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-8bit vt200-8bit )
( cd usr/share/terminfo/v ; rm -rf vt200-old )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-old vt200-old )
( cd usr/share/terminfo/v ; rm -rf vt200-w )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-w vt200-w )
( cd usr/share/terminfo/v ; rm -rf vt220-8 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-8bit vt220-8 )
( cd usr/share/terminfo/v ; rm -rf vt220-js )
( cd usr/share/terminfo/v ; ln -sf ../v/vt200-js vt220-js )
( cd usr/share/terminfo/v ; rm -rf vt300 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320 vt300 )
( cd usr/share/terminfo/v ; rm -rf vt300-nam )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320-nam vt300-nam )
( cd usr/share/terminfo/v ; rm -rf vt300-w )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320-w vt300-w )
( cd usr/share/terminfo/v ; rm -rf vt300-w-nam )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320-w-nam vt300-w-nam )
( cd usr/share/terminfo/v ; rm -rf vt330 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt340 vt330 )
( cd usr/share/terminfo/v ; rm -rf vt400-24 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt400 vt400-24 )
( cd usr/share/terminfo/v ; rm -rf vt61.5 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt61 vt61.5 )
( cd usr/share/terminfo/x ; rm -rf x1700 )
( cd usr/share/terminfo/x ; ln -sf ../d/diablo1640 x1700 )
( cd usr/share/terminfo/x ; rm -rf x1700-lm )
( cd usr/share/terminfo/x ; ln -sf ../d/diablo1740-lm x1700-lm )
( cd usr/share/terminfo/x ; rm -rf x1720 )
( cd usr/share/terminfo/x ; ln -sf ../x/xerox1720 x1720 )
( cd usr/share/terminfo/x ; rm -rf x1750 )
( cd usr/share/terminfo/x ; ln -sf ../x/xerox1720 x1750 )
( cd usr/share/terminfo/x ; rm -rf x68k-ite )
( cd usr/share/terminfo/x ; ln -sf ../x/x68k x68k-ite )
( cd usr/share/terminfo/x ; rm -rf x820 )
( cd usr/share/terminfo/x ; ln -sf ../x/xerox820 x820 )
( cd usr/share/terminfo/x ; rm -rf xdku )
( cd usr/share/terminfo/x ; ln -sf ../t/tws2103 xdku )
( cd usr/share/terminfo/x ; rm -rf xenix )
( cd usr/share/terminfo/x ; ln -sf ../i/ibmpcx xenix )
( cd usr/share/terminfo/x ; rm -rf xerox )
( cd usr/share/terminfo/x ; ln -sf ../d/diablo1640 xerox )
( cd usr/share/terminfo/x ; rm -rf xerox-lm )
( cd usr/share/terminfo/x ; ln -sf ../d/diablo1640-lm xerox-lm )
( cd usr/share/terminfo/x ; rm -rf xl83 )
( cd usr/share/terminfo/x ; ln -sf ../c/cyb83 xl83 )
( cd usr/share/terminfo/x ; rm -rf xterm-color )
( cd usr/share/terminfo/x ; ln -sf ../n/nxterm xterm-color )
( cd usr/share/terminfo/x ; rm -rf xterm-new )
( cd usr/share/terminfo/x ; ln -sf ../x/xterm-xfree86 xterm-new )
( cd usr/share/terminfo/x ; rm -rf xterm-old )
( cd usr/share/terminfo/x ; ln -sf ../x/xterm-r6 xterm-old )
( cd usr/share/terminfo/x ; rm -rf xterms )
( cd usr/share/terminfo/x ; ln -sf ../x/xterm-24 xterms )
( cd usr/share/terminfo/x ; rm -rf xwsh )
( cd usr/share/terminfo/x ; ln -sf ../i/iris-color xwsh )
( cd usr/share/terminfo/x ; rm -rf xterm-vi )
( cd usr/share/terminfo/x ; ln -sf ../x/xterm-ic xterm-vi )
( cd usr/share/terminfo/l ; rm -rf lft-pc850 )
( cd usr/share/terminfo/l ; ln -sf ../l/lft lft-pc850 )
( cd usr/share/terminfo/l ; rm -rf luna68k )
( cd usr/share/terminfo/l ; ln -sf ../l/luna luna68k )
( cd usr/share/terminfo/n ; rm -rf nec )
( cd usr/share/terminfo/n ; ln -sf ../n/nec5520 nec )
( cd usr/share/terminfo/n ; rm -rf news )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512 news )
( cd usr/share/terminfo/n ; rm -rf nansisys )
( cd usr/share/terminfo/n ; ln -sf ../n/nansi.sys nansisys )
( cd usr/share/terminfo/n ; rm -rf nwe501-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a nwe501-a )
( cd usr/share/terminfo/n ; rm -rf nwe501-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o nwe501-o )
( cd usr/share/terminfo/n ; rm -rf ncsa-vt220-8 )
( cd usr/share/terminfo/n ; ln -sf ../n/ncsa-m ncsa-vt220-8 )
( cd usr/share/terminfo/n ; rm -rf nwp251-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a nwp251-a )
( cd usr/share/terminfo/n ; rm -rf nwp251-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o nwp251-o )
( cd usr/share/terminfo/n ; rm -rf nwp514-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-a nwp514-a )
( cd usr/share/terminfo/n ; rm -rf nwp514-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-o nwp514-o )
( cd usr/share/terminfo/n ; rm -rf nwp518-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a nwp518-a )
( cd usr/share/terminfo/n ; rm -rf nwp518-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o nwp518-o )
( cd usr/share/terminfo/n ; rm -rf nsterm-7-m )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-m-7 nsterm-7-m )
( cd usr/share/terminfo/n ; rm -rf nsterm-7-s )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-s-7 nsterm-7-s )
( cd usr/share/terminfo/n ; rm -rf nsterm-c-7 )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-7-c nsterm-c-7 )
( cd usr/share/terminfo/n ; rm -rf nansisysk )
( cd usr/share/terminfo/n ; ln -sf ../n/nansi.sysk nansisysk )
( cd usr/share/terminfo/n ; rm -rf nsterm-acs-c-s )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-c-s-acs nsterm-acs-c-s )
( cd usr/share/terminfo/n ; rm -rf nsterm-acs-m-s )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-m-s-acs nsterm-acs-m-s )
( cd usr/share/terminfo/n ; rm -rf newscbm )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513 newscbm )
( cd usr/share/terminfo/n ; rm -rf news-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-a news-a )
( cd usr/share/terminfo/n ; rm -rf news-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-o news-o )
( cd usr/share/terminfo/n ; rm -rf news31 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513 news31 )
( cd usr/share/terminfo/n ; rm -rf news33 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a news33 )
( cd usr/share/terminfo/n ; rm -rf news40 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512 news40 )
( cd usr/share/terminfo/n ; rm -rf news42 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-a news42 )
( cd usr/share/terminfo/n ; rm -rf nwe501 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513 nwe501 )
( cd usr/share/terminfo/n ; rm -rf nwp514 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512 nwp514 )
( cd usr/share/terminfo/n ; rm -rf nwp518 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513 nwp518 )
( cd usr/share/terminfo/n ; rm -rf nsterm-7-c-s )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-c-s-7 nsterm-7-c-s )
( cd usr/share/terminfo/n ; rm -rf nsterm-7-m-s )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-m-s-7 nsterm-7-m-s )
( cd usr/share/terminfo/n ; rm -rf news28-a )
( cd usr/share/terminfo/n ; ln -sf ../n/news29 news28-a )
( cd usr/share/terminfo/n ; rm -rf news31-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a news31-a )
( cd usr/share/terminfo/n ; rm -rf news31-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o news31-o )
( cd usr/share/terminfo/n ; rm -rf news40-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-a news40-a )
( cd usr/share/terminfo/n ; rm -rf news40-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp512-o news40-o )
( cd usr/share/terminfo/n ; rm -rf nwp-511 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp511 nwp-511 )
( cd usr/share/terminfo/n ; rm -rf nwp-517 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp517 nwp-517 )
( cd usr/share/terminfo/n ; rm -rf nsterm-acs-c )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-c-acs nsterm-acs-c )
( cd usr/share/terminfo/n ; rm -rf nsterm-acs-m )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-m-acs nsterm-acs-m )
( cd usr/share/terminfo/n ; rm -rf nsterm-acs-s )
( cd usr/share/terminfo/n ; ln -sf ../n/nsterm-s-acs nsterm-acs-s )
( cd usr/share/terminfo/n ; rm -rf nwp-517-w )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp517-w nwp-517-w )
( cd usr/share/terminfo/n ; rm -rf newscbm-a )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a newscbm-a )
( cd usr/share/terminfo/n ; rm -rf newscbm-o )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-o newscbm-o )
( cd usr/share/terminfo/n ; rm -rf newscbm33 )
( cd usr/share/terminfo/n ; ln -sf ../n/nwp513-a newscbm33 )
( cd usr/share/terminfo/u ; rm -rf uniterm49 )
( cd usr/share/terminfo/u ; ln -sf ../u/uniterm uniterm49 )
( cd usr/share/terminfo/v ; rm -rf vip7800-H )
( cd usr/share/terminfo/v ; ln -sf ../v/vip-H vip7800-H )
( cd usr/share/terminfo/v ; rm -rf vip7800-w )
( cd usr/share/terminfo/v ; ln -sf ../v/vip-w vip7800-w )
( cd usr/share/terminfo/v ; rm -rf v200-nam )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-nam v200-nam )
( cd usr/share/terminfo/v ; rm -rf v320n )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320nam v320n )
( cd usr/share/terminfo/v ; rm -rf vc103 )
( cd usr/share/terminfo/v ; ln -sf ../v/vc303 vc103 )
( cd usr/share/terminfo/v ; rm -rf vc203 )
( cd usr/share/terminfo/v ; ln -sf ../v/vc303 vc203 )
( cd usr/share/terminfo/v ; rm -rf vs100 )
( cd usr/share/terminfo/v ; ln -sf ../x/xterm-24 vs100 )
( cd usr/share/terminfo/v ; rm -rf vt-61 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt61 vt-61 )
( cd usr/share/terminfo/v ; rm -rf vt200 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220 vt200 )
( cd usr/share/terminfo/v ; rm -rf vt300 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320 vt300 )
( cd usr/share/terminfo/v ; rm -rf vt330 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt340 vt330 )
( cd usr/share/terminfo/v ; rm -rf vt100-bot-s )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-s-bot vt100-bot-s )
( cd usr/share/terminfo/v ; rm -rf viewpoint3a+ )
( cd usr/share/terminfo/v ; ln -sf ../v/vp3a+ viewpoint3a+ )
( cd usr/share/terminfo/v ; rm -rf vt100-nam-w )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-w-nam vt100-nam-w )
( cd usr/share/terminfo/v ; rm -rf vt100-s-top )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-s vt100-s-top )
( cd usr/share/terminfo/v ; rm -rf vt100-w-nav )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-nav-w vt100-w-nav )
( cd usr/share/terminfo/v ; rm -rf vt100-top-s )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-s vt100-top-s )
( cd usr/share/terminfo/v ; rm -rf viewpoint60 )
( cd usr/share/terminfo/v ; ln -sf ../v/vp60 viewpoint60 )
( cd usr/share/terminfo/v ; rm -rf viewpoint90 )
( cd usr/share/terminfo/v ; ln -sf ../v/vp90 viewpoint90 )
( cd usr/share/terminfo/v ; rm -rf vt200-8bit )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-8bit vt200-8bit )
( cd usr/share/terminfo/v ; rm -rf vt300-w-nam )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320-w-nam vt300-w-nam )
( cd usr/share/terminfo/v ; rm -rf visual603 )
( cd usr/share/terminfo/v ; ln -sf ../v/vi603 visual603 )
( cd usr/share/terminfo/v ; rm -rf vt100-nam )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100nam vt100-nam )
( cd usr/share/terminfo/v ; rm -rf vip7800-Hw )
( cd usr/share/terminfo/v ; ln -sf ../v/vip-Hw vip7800-Hw )
( cd usr/share/terminfo/v ; rm -rf vt200-old )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-old vt200-old )
( cd usr/share/terminfo/v ; rm -rf vc403a )
( cd usr/share/terminfo/v ; ln -sf ../v/vc303a vc403a )
( cd usr/share/terminfo/v ; rm -rf vc414h )
( cd usr/share/terminfo/v ; ln -sf ../v/vc414 vc414h )
( cd usr/share/terminfo/v ; rm -rf vt61.5 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt61 vt61.5 )
( cd usr/share/terminfo/v ; rm -rf vt100-bm-o )
( cd usr/share/terminfo/v ; ln -sf ../n/nwp512-o vt100-bm-o )
( cd usr/share/terminfo/v ; rm -rf vt100-w-am )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100-w vt100-w-am )
( cd usr/share/terminfo/v ; rm -rf vt100-am )
( cd usr/share/terminfo/v ; ln -sf ../v/vt100 vt100-am )
( cd usr/share/terminfo/v ; rm -rf vt100-bm )
( cd usr/share/terminfo/v ; ln -sf ../n/nwp512 vt100-bm )
( cd usr/share/terminfo/v ; rm -rf vt220-js )
( cd usr/share/terminfo/v ; ln -sf ../v/vt200-js vt220-js )
( cd usr/share/terminfo/v ; rm -rf vt200-8 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-8bit vt200-8 )
( cd usr/share/terminfo/v ; rm -rf vt200-w )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-w vt200-w )
( cd usr/share/terminfo/v ; rm -rf vt220-8 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt220-8bit vt220-8 )
( cd usr/share/terminfo/v ; rm -rf vt300-w )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320-w vt300-w )
( cd usr/share/terminfo/v ; rm -rf vt300-nam )
( cd usr/share/terminfo/v ; ln -sf ../v/vt320-nam vt300-nam )
( cd usr/share/terminfo/v ; rm -rf vt400-24 )
( cd usr/share/terminfo/v ; ln -sf ../v/vt400 vt400-24 )
( cd usr/share/terminfo/v ; rm -rf vs100-x10 )
( cd usr/share/terminfo/v ; ln -sf ../x/x10term vs100-x10 )
( cd usr/share/terminfo/x ; rm -rf x68k-ite )
( cd usr/share/terminfo/x ; ln -sf ../x/x68k x68k-ite )
( cd usr/share/terminfo/x ; rm -rf xterm-new )
( cd usr/share/terminfo/x ; ln -sf ../x/xterm-xfree86 xterm-new )
( cd usr/share/terminfo/x ; rm -rf xterm-old )
( cd usr/share/terminfo/x ; ln -sf ../x/xterm-r6 xterm-old )
( cd usr/share/terminfo/x ; rm -rf xterm-color )
( cd usr/share/terminfo/x ; ln -sf ../n/nxterm xterm-color )
( cd usr/share/terminfo/x ; rm -rf xterms )
( cd usr/share/terminfo/x ; ln -sf ../x/xterm-24 xterms )
( cd usr/share/terminfo/x ; rm -rf xterm-vi )
( cd usr/share/terminfo/x ; ln -sf ../x/xterm-ic xterm-vi )
